@@ -17,10 +17,11 @@ import logging
 import importlib
 
 import sqlalchemy
-from sqlalchemy import create_engine, orm
+from sqlalchemy import create_engine, orm, Table
 from sqlalchemy.sql.elements import BinaryExpression
 
 from . import model
+from .column_types import WriteOnlyColumn
 from .utils import xlate
 from .doc_utils import (
     process_expression,
@@ -52,7 +53,9 @@ class DB(object):
         echo: (bool) : log actions in database engine
     """
 
-    def __init__(self, config, model_class=None, checkfirst=True, echo=False):
+    def __init__(
+            self, config, model_class=None, checkfirst=True, echo=False,
+            *args, **kwargs):
 
         # not a fan of this
         if config != ":memory:":
@@ -63,6 +66,9 @@ class DB(object):
         for key in sqlalchemy.__all__:
             self.__setattr__(key, sqlalchemy.__dict__.__getitem__(key))
 
+        # column types
+        self.__setattr__('WriteOnlyColumn', WriteOnlyColumn)
+
         # these are being added on an as-needed basis
         orm_functions = ["relationship", "aliased", "lazyload"]
         for key in orm_functions:
@@ -75,7 +81,8 @@ class DB(object):
         self.Model.db = self
 
         # now create_session is done after importing models
-        self.session = self.create_session(checkfirst=checkfirst, echo=echo)
+        self.session = self.create_session(
+            checkfirst=checkfirst, echo=echo, *args, **kwargs)
 
     @staticmethod
     def load_model_class(model_class=None):
@@ -99,7 +106,7 @@ class DB(object):
         if model_class is None:
             return model.Model
 
-    def create_engine(self, echo=False):
+    def create_engine(self, echo=False, *args, **kwargs):
         """ create_engine
 
         Basically a pass through to sqlalchemy.
@@ -117,7 +124,7 @@ class DB(object):
         self.engine = create_engine(self.config, echo=echo)
         return self.engine
 
-    def create_session(self, checkfirst=True, echo=False):
+    def create_session(self, checkfirst=True, echo=False, *args, **kwargs):
         """create_session
 
         This function instantiates an engine, and connects to the database.
@@ -136,7 +143,7 @@ class DB(object):
         Returns:
             session (obj)
         """
-        engine = create_engine(self.config, echo=echo)
+        engine = create_engine(self.config, echo=echo, *args, **kwargs)
         engine.connect()
 
         session = orm.sessionmaker(bind=engine)()
@@ -193,7 +200,7 @@ class DB(object):
         """
         for cls in self.Model._decl_class_registry.values():
             if hasattr(cls, "__table__"):
-                if isinstance(cls.__table__, self.Table):
+                if isinstance(cls.__table__, Table):
                     self.apply_db(cls)
 
     def apply_db(self, cls):
@@ -325,7 +332,7 @@ class DB(object):
             columns = [
                 key
                 for key in cls.__dict__.keys()
-                if key not in cls._get_serial_stop_list(cls)
+                if key not in cls._get_serial_stop_list()
             ]
 
         for key in columns:
@@ -344,20 +351,20 @@ class DB(object):
                         "readOnly": True,
                         "unknown": str(value.expression),
                     }
-                self._filter_column_props(column_props, item_dict)
+                _filter_column_props(column_props, item_dict)
                 _post_value(key, item_dict)
 
             elif isinstance(value, property):
 
                 item_dict = _property(cls, key, value)
-                self._filter_column_props(column_props, item_dict)
+                _filter_column_props(column_props, item_dict)
                 _post_value(key, item_dict)
 
             elif callable(value):
 
                 item_dict = _function(value)
                 if item_dict is not None:
-                    self._filter_column_props(column_props, item_dict)
+                    _filter_column_props(column_props, item_dict)
                     _post_value(key, item_dict)
 
             else:
@@ -370,24 +377,6 @@ class DB(object):
 
         return doc
 
-    @staticmethod
-    def _filter_column_props(column_props, item_dict):
-        """ _filter_column_props
-
-        This function removes unneeded column properties.
-
-        Args:
-            column_props: (dict) : Only props to return
-            item_dict: (dict) : the dict set to processes
-
-        Returns:
-            dict
-        """
-        if column_props is not None:
-            for prop_key in list(item_dict.keys()):
-                if prop_key not in column_props:
-                    del item_dict[prop_key]
-
     def _process_table_args(self, cls):
 
         table_args = cls.__dict__.get('__table_args__')
@@ -435,3 +424,21 @@ class DB(object):
             dict
         """
         return process_expression(getattr(cls, column_name).expression)
+
+
+def _filter_column_props(column_props, item_dict):
+    """ _filter_column_props
+
+    This function removes unneeded column properties.
+
+    Args:
+        column_props: (dict) : Only props to return
+        item_dict: (dict) : the dict set to processes
+
+    Returns:
+        dict
+    """
+    if column_props is not None:
+        for prop_key in list(item_dict.keys()):
+            if prop_key not in column_props:
+                del item_dict[prop_key]
