@@ -4,7 +4,9 @@ This module implements a base model to be used for table creation.
 
 """
 import json
+from sqlalchemy import inspect
 from sqlalchemy.ext.declarative import as_declarative
+from sqlalchemy.orm.attributes import InstrumentedAttribute
 
 from .utils import xlate
 from .serializers import _eval_value, STOP_VALUE, SERIAL_STOPLIST
@@ -78,28 +80,30 @@ class Model(object):
 
             then this function returns 'User'
         """
-        return cls.db.inspect(cls).class_.__name__
+        return cls.__name__
 
-    def _get_serial_stop_list(self):
+    @classmethod
+    def _get_serial_stop_list(cls):
         """Return default stop list, class stop list."""
-        if self.SERIAL_STOPLIST is None:
+        if cls.SERIAL_STOPLIST is None:
             serial_stoplist = []
         else:
-            serial_stoplist = self.SERIAL_STOPLIST
+            serial_stoplist = cls.SERIAL_STOPLIST
         if not isinstance(serial_stoplist, list):
             raise ValueError(
                 "SERIAL_STOPLIST must be a list of one or more fields that"
                 "would not be included in a serialization."
             )
         return (
-            self._DEFAULT_SERIAL_STOPLIST + SERIAL_STOPLIST + serial_stoplist
+            cls._DEFAULT_SERIAL_STOPLIST + SERIAL_STOPLIST + serial_stoplist
         )
 
-    def _get_relationship(self, field):
+    @classmethod
+    def _get_relationship(cls, field):
         """_get_relationship
 
         Usage:
-            self,_get_relationship(field)
+            _get_relationship(field)
         Used for iterating through relationships to determine how deep to go
         with serialization.
 
@@ -107,14 +111,15 @@ class Model(object):
             if a relationship is found, returns the relationship
             otherwise None
         """
-        tmp = self.db.inspect(self.__class__).relationships
+        tmp = inspect(cls).relationships
 
         if field in tmp.keys():
             return tmp[field]
 
         return None
 
-    def _relations_info(self, field):
+    @classmethod
+    def _relations_info(cls, field):
         """
         This function provides info to help determine how far down
         the path to go on serialization of a relationship field.
@@ -123,35 +128,34 @@ class Model(object):
         One to many
         join_depth
         """
-        relation = self._get_relationship(field)
+        relation = cls._get_relationship(field)
         if relation is None:
             return None
 
         return {
-            "self-referential": relation.target.name == self.__tablename__,
-            # these are not currently used.
-            # intuitively, it seems like a good idea, but I am not sure why.
-            # Accordingly, these may be removed without warning, since
-            # program structure and testing does not seem to require them.
+            "self-referential": relation.target.name == cls.__tablename__,
             "uselist": relation.uselist,
             "join_depth": relation.join_depth,
+            "lazy": relation.lazy
         }
 
-    def _has_self_ref(self):
+    @classmethod
+    def _has_self_ref(cls):
         """_has_self_ref
 
         This function returns True if one or more relationships are self-
         referential.
         """
-        for field in self.get_serial_fields():
-            rel_info = self._relations_info(field)
+        for field in cls.get_serial_fields():
+            rel_info = cls._relations_info(field)
             if rel_info is not None:
                 if rel_info["self-referential"]:
                     return True
 
         return False
 
-    def get_serial_fields(self):
+    @classmethod
+    def get_serial_fields(cls):
         """get_serial_fields
 
         This function returns a list of table properties that will be used in
@@ -166,22 +170,27 @@ class Model(object):
         Returns:
             serial_fields (list) : current list of fields
         """
-        if self.SERIAL_FIELDS is not None:
-            if not isinstance(self.SERIAL_FIELDS, list):
+        if cls.SERIAL_FIELDS is not None:
+            if not isinstance(cls.SERIAL_FIELDS, list):
                 raise ValueError(
                     "SERIAL_FIELDS must be in the form of a list: {}".format(
-                        self.SERIAL_FIELDS
+                        cls.SERIAL_FIELDS
                     )
                 )
-            return self.SERIAL_FIELDS
+            return cls.SERIAL_FIELDS
 
-        fields = [field for field in dir(self) if not field.startswith("_")]
+        fields = [field for field in dir(cls) if not field.startswith("_")]
 
-        return list(set(fields) - set(self._get_serial_stop_list()))
+        return list(set(fields) - set(cls._get_serial_stop_list()))
 
     def to_dict(
-            self, to_camel_case=True, level_limits=None, sort=False,
-            serial_fields=None, serial_field_relations=None):
+        self,
+        to_camel_case=True,
+        level_limits=None,
+        sort=False,
+        serial_fields=None,
+        serial_field_relations=None,
+    ):
         """
         Returns columns in a dict. The point of this is to make a useful
         default. However, this can't be expected to cover every possibility,
@@ -213,7 +222,6 @@ class Model(object):
         Returns:
             (dict) | a dictionary of fields and values
         """
-        self.db.session.flush()
         if level_limits is None:
             level_limits = set()
 
@@ -247,22 +255,31 @@ class Model(object):
 
             value = self.__getattribute__(key)
 
-            if callable(value):
-                value = value()
+            if rel_info and rel_info['lazy'] == 'dynamic':
+                value = [item for item in value.all()]
 
-            res = _eval_value(
-                value,
-                to_camel_case,
-                level_limits,
-                source_class=self._class(),
-                serial_field_relations=serial_field_relations,
-            )
+            status = True
+            if self._is_write_only(key):
+                if value is not None:
+                    status = False
 
-            if to_camel_case:
-                key = xlate(key, camel_case=True)
+            if status:
+                if callable(value):
+                    value = value()
 
-            if res != STOP_VALUE:
-                result[key] = res
+                res = _eval_value(
+                    value,
+                    to_camel_case,
+                    level_limits,
+                    source_class=self._class(),
+                    serial_field_relations=serial_field_relations,
+                )
+
+                if to_camel_case:
+                    key = xlate(key, camel_case=True)
+
+                if res != STOP_VALUE:
+                    result[key] = res
 
         if self._class() not in level_limits:
             level_limits.add(self._class())
@@ -297,8 +314,8 @@ class Model(object):
                 sorted.
             indent: (integer : None) The number of spaces to indent to improve
                 readability.
-            serial_fields (None | list) : a list of fields to be substituted for
-                `cls.SERIAL_FIELDS`
+            serial_fields (None | list) : a list of fields to be substituted
+                for `cls.SERIAL_FIELDS`
             serial_field_relations (None | dict) : To enable a more nuanced
                 control of relations objects, the name of a downstream class
                 and a list of fields to be typically included with the related
@@ -441,7 +458,7 @@ class Model(object):
             error_dict (None : dict ) | a dict that contains an error list
         """
         errors = []
-        tmp = self.db.inspect(self.__class__).all_orm_descriptors
+        tmp = inspect(self.__class__).all_orm_descriptors
         null_cols = self._null_columns()
         for column in null_cols:
             expr = tmp[column].expression
@@ -473,7 +490,7 @@ class Model(object):
                 for key, error in errors.items():
                     new_errors.append(dict([xlate(key), error]))
                 errors = new_errors
-            return False, {'ForeignKeys': errors}
+            return False, {"ForeignKeys": errors}
 
         return True, None
 
@@ -489,12 +506,12 @@ class Model(object):
         errors = []
         for key, value in self._extract_foreign_keys().items():
             column_params = self.db.doc_column(self.__class__, key)
-            key_value =  getattr(self, key)
+            key_value = getattr(self, key)
             if key_value is not None:
-                if column_params['nullable'] is False:
+                if column_params["nullable"] is False:
                     # foreign key
-                    table, id_ = value['foreign_key'].split('.')
-                    select = f'select {id_} from {table} where {id_} = {id_}'
+                    table, id_ = value["foreign_key"].split(".")
+                    select = f"select {id_} from {table} where {id_} = {id_}"
                     res = self.db.session.execute(select).first()
                     if res is None:
                         errors.append(
@@ -505,7 +522,8 @@ class Model(object):
         else:
             return True, None
 
-    def _extract_foreign_keys(self):
+    @classmethod
+    def _extract_foreign_keys(cls):
         """_extract_foreign_keys
 
         This function walks the document dictionary and returns the
@@ -516,8 +534,24 @@ class Model(object):
         return dict(
             [
                 (key, value)
-                for key, value in self.db.doc_table(
-                    self.__class__, column_props=['foreign_key'])[self._class()]['properties'].items()
+                for key, value in cls.db.doc_table(
+                    cls, column_props=["foreign_key"]
+                )[cls._class()]["properties"].items()
                 if value
             ]
         )
+
+    @classmethod
+    def _is_write_only(cls, column_name):
+        """ _is_write_only
+
+        This function returns True if the column has 'writeOnly' True
+        in the info field.
+        """
+        tmp = cls.__dict__[column_name]
+        if isinstance(tmp, InstrumentedAttribute):
+            if isinstance(tmp.expression, cls.db.Column):
+                if "writeOnly" in tmp.expression.info:
+                    value = tmp.expression.info["writeOnly"]
+                    return value
+        return False
